from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AresStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_CONNECTION_STATUS: _ClassVar[AresStatus]
    CONNECTED: _ClassVar[AresStatus]
    DISCONNECTED: _ClassVar[AresStatus]
UNKNOWN_CONNECTION_STATUS: AresStatus
CONNECTED: AresStatus
DISCONNECTED: AresStatus

class ConnectionStatusRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ConnectionStatus(_message.Message):
    __slots__ = ("status", "info")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    status: AresStatus
    info: str
    def __init__(self, status: _Optional[_Union[AresStatus, str]] = ..., info: _Optional[str] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'analyzing/analysis.proto')
_sym_db = _symbol_database.Default()
from .. import ares_outcome_enum_pb2 as ares__outcome__enum__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18analyzing/analysis.proto\x12\x18ares.datamodel.analyzing\x1a\x17ares_outcome_enum.proto"y\n\x08Analysis\x12\x0e\n\x06result\x18\x01 \x01(\x02\x121\n\x10analysis_outcome\x18\x02 \x01(\x0e2\x17.ares.datamodel.Outcome\x12\x19\n\x0cerror_string\x18\x03 \x01(\tH\x00\x88\x01\x01B\x0f\n\r_error_stringb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'analyzing.analysis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ANALYSIS']._serialized_start = 79
    _globals['_ANALYSIS']._serialized_end = 200


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_analysis_service.proto')
_sym_db = _symbol_database.Default()
from . import validation_result_pb2 as validation__result__pb2
from .analyzing import analysis_pb2 as analyzing_dot_analysis__pb2
from . import ares_struct_pb2 as ares__struct__pb2
from . import ares_data_schema_pb2 as ares__data__schema__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bares_analysis_service.proto\x12\rares.services\x1a\x17validation_result.proto\x1a\x18analyzing/analysis.proto\x1a\x11ares_struct.proto\x1a\x16ares_data_schema.proto"\x80\x01\n\x0fAnalysisRequest\x12\x13\n\x0banalyzer_id\x18\x01 \x01(\t\x12*\n\x06inputs\x18\x02 \x01(\x0b2\x1a.ares.datamodel.AresStruct\x12,\n\x08settings\x18\x03 \x01(\x0b2\x1a.ares.datamodel.AresStruct"c\n\x16InputValidationRequest\x12\x13\n\x0banalyzer_id\x18\x01 \x01(\t\x124\n\x0cinput_schema\x18\x02 \x01(\x0b2\x1e.ares.datamodel.AresDataSchema"0\n\x19AnalyzerParametersRequest\x12\x13\n\x0banalyzer_id\x18\x01 \x01(\t"U\n\x1aAnalyzerParametersResponse\x127\n\x0fanalysis_schema\x18\x01 \x01(\x0b2\x1e.ares.datamodel.AresDataSchema2\xad\x02\n\x13AresAnalysisService\x12Y\n\x0eValidateInputs\x12%.ares.services.InputValidationRequest\x1a .ares.datamodel.ValidationResult\x12M\n\x07Analyze\x12\x1e.ares.services.AnalysisRequest\x1a".ares.datamodel.analyzing.Analysis\x12l\n\x15GetAnalyzerParameters\x12(.ares.services.AnalyzerParametersRequest\x1a).ares.services.AnalyzerParametersResponseb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_analysis_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ANALYSISREQUEST']._serialized_start = 141
    _globals['_ANALYSISREQUEST']._serialized_end = 269
    _globals['_INPUTVALIDATIONREQUEST']._serialized_start = 271
    _globals['_INPUTVALIDATIONREQUEST']._serialized_end = 370
    _globals['_ANALYZERPARAMETERSREQUEST']._serialized_start = 372
    _globals['_ANALYZERPARAMETERSREQUEST']._serialized_end = 420
    _globals['_ANALYZERPARAMETERSRESPONSE']._serialized_start = 422
    _globals['_ANALYZERPARAMETERSRESPONSE']._serialized_end = 507
    _globals['_ARESANALYSISSERVICE']._serialized_start = 510
    _globals['_ARESANALYSISSERVICE']._serialized_end = 811


import datetime

from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Severity(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNSPECIFIED: _ClassVar[Severity]
    INFO: _ClassVar[Severity]
    WARNING: _ClassVar[Severity]
    ERROR: _ClassVar[Severity]
    DANGER: _ClassVar[Severity]
    SUCCESS: _ClassVar[Severity]
UNSPECIFIED: Severity
INFO: Severity
WARNING: Severity
ERROR: Severity
DANGER: Severity
SUCCESS: Severity

class SubscriptionRequest(_message.Message):
    __slots__ = ("clientId",)
    CLIENTID_FIELD_NUMBER: _ClassVar[int]
    clientId: str
    def __init__(self, clientId: _Optional[str] = ...) -> None: ...

class NotificationsList(_message.Message):
    __slots__ = ("notifications",)
    NOTIFICATIONS_FIELD_NUMBER: _ClassVar[int]
    notifications: _containers.RepeatedCompositeFieldContainer[AresNotification]
    def __init__(self, notifications: _Optional[_Iterable[_Union[AresNotification, _Mapping]]] = ...) -> None: ...

class AresNotification(_message.Message):
    __slots__ = ("title", "message", "notification_severity", "timestamp", "loiter")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    NOTIFICATION_SEVERITY_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    LOITER_FIELD_NUMBER: _ClassVar[int]
    title: str
    message: str
    notification_severity: Severity
    timestamp: _timestamp_pb2.Timestamp
    loiter: bool
    def __init__(self, title: _Optional[str] = ..., message: _Optional[str] = ..., notification_severity: _Optional[_Union[Severity, str]] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., loiter: bool = ...) -> None: ...



from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ServerStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    IDLE: _ClassVar[ServerStatus]
    BUSY: _ClassVar[ServerStatus]
    ERROR: _ClassVar[ServerStatus]
    STOPPING: _ClassVar[ServerStatus]
    STOPPED: _ClassVar[ServerStatus]
IDLE: ServerStatus
BUSY: ServerStatus
ERROR: ServerStatus
STOPPING: ServerStatus
STOPPED: ServerStatus

class ServerInfoResponse(_message.Message):
    __slots__ = ("server_name", "version")
    SERVER_NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    server_name: str
    version: str
    def __init__(self, server_name: _Optional[str] = ..., version: _Optional[str] = ...) -> None: ...

class ServerStatusResponse(_message.Message):
    __slots__ = ("server_status", "status_message")
    SERVER_STATUS_FIELD_NUMBER: _ClassVar[int]
    STATUS_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    server_status: ServerStatus
    status_message: str
    def __init__(self, server_status: _Optional[_Union[ServerStatus, str]] = ..., status_message: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NullValue(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NULL_VALUE: _ClassVar[NullValue]

class UnitValue(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNIT_VALUE: _ClassVar[UnitValue]
NULL_VALUE: NullValue
UNIT_VALUE: UnitValue

class AresStruct(_message.Message):
    __slots__ = ("fields",)
    class FieldsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: AresValue
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[AresValue, _Mapping]] = ...) -> None: ...
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    fields: _containers.MessageMap[str, AresValue]
    def __init__(self, fields: _Optional[_Mapping[str, AresValue]] = ...) -> None: ...

class AresValue(_message.Message):
    __slots__ = ("null_value", "bool_value", "string_value", "number_value", "bytes_value", "string_array_value", "number_array_value", "list_value", "struct_value", "unit_value", "function_value")
    NULL_VALUE_FIELD_NUMBER: _ClassVar[int]
    BOOL_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_FIELD_NUMBER: _ClassVar[int]
    NUMBER_VALUE_FIELD_NUMBER: _ClassVar[int]
    BYTES_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    NUMBER_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    LIST_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRUCT_VALUE_FIELD_NUMBER: _ClassVar[int]
    UNIT_VALUE_FIELD_NUMBER: _ClassVar[int]
    FUNCTION_VALUE_FIELD_NUMBER: _ClassVar[int]
    null_value: NullValue
    bool_value: bool
    string_value: str
    number_value: float
    bytes_value: bytes
    string_array_value: StringArray
    number_array_value: NumberArray
    list_value: AresValueList
    struct_value: AresStruct
    unit_value: UnitValue
    function_value: FunctionValue
    def __init__(self, null_value: _Optional[_Union[NullValue, str]] = ..., bool_value: bool = ..., string_value: _Optional[str] = ..., number_value: _Optional[float] = ..., bytes_value: _Optional[bytes] = ..., string_array_value: _Optional[_Union[StringArray, _Mapping]] = ..., number_array_value: _Optional[_Union[NumberArray, _Mapping]] = ..., list_value: _Optional[_Union[AresValueList, _Mapping]] = ..., struct_value: _Optional[_Union[AresStruct, _Mapping]] = ..., unit_value: _Optional[_Union[UnitValue, str]] = ..., function_value: _Optional[_Union[FunctionValue, _Mapping]] = ...) -> None: ...

class FunctionValue(_message.Message):
    __slots__ = ("function_id",)
    FUNCTION_ID_FIELD_NUMBER: _ClassVar[int]
    function_id: str
    def __init__(self, function_id: _Optional[str] = ...) -> None: ...

class StringArray(_message.Message):
    __slots__ = ("strings",)
    STRINGS_FIELD_NUMBER: _ClassVar[int]
    strings: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, strings: _Optional[_Iterable[str]] = ...) -> None: ...

class NumberArray(_message.Message):
    __slots__ = ("numbers",)
    NUMBERS_FIELD_NUMBER: _ClassVar[int]
    numbers: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, numbers: _Optional[_Iterable[float]] = ...) -> None: ...

class AresValueList(_message.Message):
    __slots__ = ("values",)
    VALUES_FIELD_NUMBER: _ClassVar[int]
    values: _containers.RepeatedCompositeFieldContainer[AresValue]
    def __init__(self, values: _Optional[_Iterable[_Union[AresValue, _Mapping]]] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_scripting_service.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cares_scripting_service.proto\x12\rares.services"(\n\x16ScriptExecutionRequest\x12\x0e\n\x06script\x18\x01 \x01(\t"\'\n\x15ScriptExecutionOutput\x12\x0e\n\x06output\x18\x01 \x01(\t2v\n\x14AresScriptingService\x12^\n\rExecuteScript\x12%.ares.services.ScriptExecutionRequest\x1a$.ares.services.ScriptExecutionOutput0\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_scripting_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SCRIPTEXECUTIONREQUEST']._serialized_start = 47
    _globals['_SCRIPTEXECUTIONREQUEST']._serialized_end = 87
    _globals['_SCRIPTEXECUTIONOUTPUT']._serialized_start = 89
    _globals['_SCRIPTEXECUTIONOUTPUT']._serialized_end = 128
    _globals['_ARESSCRIPTINGSERVICE']._serialized_start = 130
    _globals['_ARESSCRIPTINGSERVICE']._serialized_end = 248


import ares_data_schema_pb2 as _ares_data_schema_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VisualizerCapabilities(_message.Message):
    __slots__ = ("timeout_seconds", "settings_schema")
    TIMEOUT_SECONDS_FIELD_NUMBER: _ClassVar[int]
    SETTINGS_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    timeout_seconds: int
    settings_schema: _ares_data_schema_pb2.AresDataSchema
    def __init__(self, timeout_seconds: _Optional[int] = ..., settings_schema: _Optional[_Union[_ares_data_schema_pb2.AresDataSchema, _Mapping]] = ...) -> None: ...



from templates import step_template_pb2 as _step_template_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExperimentTemplate(_message.Message):
    __slots__ = ("unique_id", "step_templates", "name", "analyzer_id", "analyzer_maps", "resolved")
    class AnalyzerMapsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    STEP_TEMPLATES_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ANALYZER_ID_FIELD_NUMBER: _ClassVar[int]
    ANALYZER_MAPS_FIELD_NUMBER: _ClassVar[int]
    RESOLVED_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    step_templates: _containers.RepeatedCompositeFieldContainer[_step_template_pb2.StepTemplate]
    name: str
    analyzer_id: str
    analyzer_maps: _containers.ScalarMap[str, str]
    resolved: bool
    def __init__(self, unique_id: _Optional[str] = ..., step_templates: _Optional[_Iterable[_Union[_step_template_pb2.StepTemplate, _Mapping]]] = ..., name: _Optional[str] = ..., analyzer_id: _Optional[str] = ..., analyzer_maps: _Optional[_Mapping[str, str]] = ..., resolved: bool = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'templates/variable_allocation.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#templates/variable_allocation.proto\x12\x18ares.datamodel.templates"~\n\x12VariableAllocation\x12\x11\n\tunqiue_id\x18\x01 \x01(\t\x12=\n\rvariable_type\x18\x02 \x01(\x0e2&.ares.datamodel.templates.VariableType\x12\x16\n\x0eparameter_name\x18\x03 \x01(\t*\xae\x01\n\x0cVariableType\x12\x13\n\x0fVAR_UNSPECIFIED\x10\x00\x12\x18\n\x14CAMPAIGN_RESULT_PATH\x10\x01\x12\x1a\n\x16EXPERIMENT_RESULT_PATH\x10\x02\x12\x1c\n\x18PREVIOUS_EXPERIMENT_PATH\x10\x03\x12\x18\n\x14CAMPAIGN_MISC_FOLDER\x10\x04\x12\x1b\n\x17CAMPAIGN_STARTUP_FOLDER\x10\x05b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'templates.variable_allocation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_VARIABLETYPE']._serialized_start = 194
    _globals['_VARIABLETYPE']._serialized_end = 368
    _globals['_VARIABLEALLOCATION']._serialized_start = 65
    _globals['_VARIABLEALLOCATION']._serialized_end = 191


from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeviceLoggingSettings(_message.Message):
    __slots__ = ("device_id", "logging_type", "interval_ms", "deltas")
    class LoggingType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[DeviceLoggingSettings.LoggingType]
        INTERVAL: _ClassVar[DeviceLoggingSettings.LoggingType]
        ON_CHANGE: _ClassVar[DeviceLoggingSettings.LoggingType]
    NONE: DeviceLoggingSettings.LoggingType
    INTERVAL: DeviceLoggingSettings.LoggingType
    ON_CHANGE: DeviceLoggingSettings.LoggingType
    class DeltasEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: float
        def __init__(self, key: _Optional[str] = ..., value: _Optional[float] = ...) -> None: ...
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    LOGGING_TYPE_FIELD_NUMBER: _ClassVar[int]
    INTERVAL_MS_FIELD_NUMBER: _ClassVar[int]
    DELTAS_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    logging_type: DeviceLoggingSettings.LoggingType
    interval_ms: int
    deltas: _containers.ScalarMap[str, float]
    def __init__(self, device_id: _Optional[str] = ..., logging_type: _Optional[_Union[DeviceLoggingSettings.LoggingType, str]] = ..., interval_ms: _Optional[int] = ..., deltas: _Optional[_Mapping[str, float]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OperationalState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNSPECIFIED: _ClassVar[OperationalState]
    INACTIVE: _ClassVar[OperationalState]
    ACTIVE: _ClassVar[OperationalState]
    ERROR: _ClassVar[OperationalState]
UNSPECIFIED: OperationalState
INACTIVE: OperationalState
ACTIVE: OperationalState
ERROR: OperationalState

class DeviceOperationalStatus(_message.Message):
    __slots__ = ("operational_state", "message")
    OPERATIONAL_STATE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    operational_state: OperationalState
    message: str
    def __init__(self, operational_state: _Optional[_Union[OperationalState, str]] = ..., message: _Optional[str] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_data_schema.proto')
_sym_db = _symbol_database.Default()
from . import ares_data_type_pb2 as ares__data__type__pb2
from . import ares_struct_pb2 as ares__struct__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16ares_data_schema.proto\x12\x0eares.datamodel\x1a\x14ares_data_type.proto\x1a\x11ares_struct.proto"\x98\x01\n\x0eAresDataSchema\x12:\n\x06fields\x18\x01 \x03(\x0b2*.ares.datamodel.AresDataSchema.FieldsEntry\x1aJ\n\x0bFieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b2\x1b.ares.datamodel.SchemaEntry:\x028\x01"\xe2\x02\n\x0bSchemaEntry\x12*\n\x04type\x18\x01 \x01(\x0e2\x1c.ares.datamodel.AresDataType\x12\x10\n\x08optional\x18\x02 \x01(\x08\x12\x13\n\x0bdescription\x18\x03 \x01(\t\x12\x0c\n\x04unit\x18\x04 \x01(\t\x125\n\x0estring_choices\x18\x05 \x01(\x0b2\x1b.ares.datamodel.StringArrayH\x00\x125\n\x0enumber_choices\x18\x06 \x01(\x0b2\x1b.ares.datamodel.NumberArrayH\x00\x125\n\rstruct_schema\x18\x07 \x01(\x0b2\x1e.ares.datamodel.AresDataSchema\x128\n\x13list_element_schema\x18\x08 \x01(\x0b2\x1b.ares.datamodel.SchemaEntryB\x13\n\x11available_choicesb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_data_schema_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ARESDATASCHEMA_FIELDSENTRY']._loaded_options = None
    _globals['_ARESDATASCHEMA_FIELDSENTRY']._serialized_options = b'8\x01'
    _globals['_ARESDATASCHEMA']._serialized_start = 84
    _globals['_ARESDATASCHEMA']._serialized_end = 236
    _globals['_ARESDATASCHEMA_FIELDSENTRY']._serialized_start = 162
    _globals['_ARESDATASCHEMA_FIELDSENTRY']._serialized_end = 236
    _globals['_SCHEMAENTRY']._serialized_start = 239
    _globals['_SCHEMAENTRY']._serialized_end = 593


import ares_outcome_enum_pb2 as _ares_outcome_enum_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Analysis(_message.Message):
    __slots__ = ("result", "analysis_outcome", "error_string")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_OUTCOME_FIELD_NUMBER: _ClassVar[int]
    ERROR_STRING_FIELD_NUMBER: _ClassVar[int]
    result: float
    analysis_outcome: _ares_outcome_enum_pb2.Outcome
    error_string: str
    def __init__(self, result: _Optional[float] = ..., analysis_outcome: _Optional[_Union[_ares_outcome_enum_pb2.Outcome, str]] = ..., error_string: _Optional[str] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'device/device_state_request_filter.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(device/device_state_request_filter.proto\x12\x15ares.datamodel.device\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1egoogle/protobuf/duration.proto"\xab\x02\n\x18DeviceStateRequestFilter\x12)\n\x05start\x18\x01 \x01(\x0b2\x1a.google.protobuf.Timestamp\x12\'\n\x03end\x18\x02 \x01(\x0b2\x1a.google.protobuf.Timestamp\x12=\n\x17completed_experiment_id\x18\x03 \x01(\x0b2\x1c.google.protobuf.StringValue\x12;\n\x15completed_campaign_id\x18\x04 \x01(\x0b2\x1c.google.protobuf.StringValue\x12+\n\x08interval\x18\x05 \x01(\x0b2\x19.google.protobuf.Duration\x12\x12\n\ndevice_ids\x18\x06 \x03(\tb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.device_state_request_filter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_DEVICESTATEREQUESTFILTER']._serialized_start = 165
    _globals['_DEVICESTATEREQUESTFILTER']._serialized_end = 464


import ares_data_type_pb2 as _ares_data_type_pb2
import ares_struct_pb2 as _ares_struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AresDataSchema(_message.Message):
    __slots__ = ("fields",)
    class FieldsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: SchemaEntry
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[SchemaEntry, _Mapping]] = ...) -> None: ...
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    fields: _containers.MessageMap[str, SchemaEntry]
    def __init__(self, fields: _Optional[_Mapping[str, SchemaEntry]] = ...) -> None: ...

class SchemaEntry(_message.Message):
    __slots__ = ("type", "optional", "description", "unit", "string_choices", "number_choices", "struct_schema", "list_element_schema")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    OPTIONAL_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    STRING_CHOICES_FIELD_NUMBER: _ClassVar[int]
    NUMBER_CHOICES_FIELD_NUMBER: _ClassVar[int]
    STRUCT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    LIST_ELEMENT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    type: _ares_data_type_pb2.AresDataType
    optional: bool
    description: str
    unit: str
    string_choices: _ares_struct_pb2.StringArray
    number_choices: _ares_struct_pb2.NumberArray
    struct_schema: AresDataSchema
    list_element_schema: SchemaEntry
    def __init__(self, type: _Optional[_Union[_ares_data_type_pb2.AresDataType, str]] = ..., optional: bool = ..., description: _Optional[str] = ..., unit: _Optional[str] = ..., string_choices: _Optional[_Union[_ares_struct_pb2.StringArray, _Mapping]] = ..., number_choices: _Optional[_Union[_ares_struct_pb2.NumberArray, _Mapping]] = ..., struct_schema: _Optional[_Union[AresDataSchema, _Mapping]] = ..., list_element_schema: _Optional[_Union[SchemaEntry, _Mapping]] = ...) -> None: ...



from templates import experiment_template_pb2 as _experiment_template_pb2
from templates import parameter_metadata_pb2 as _parameter_metadata_pb2
from planning import planner_allocation_pb2 as _planner_allocation_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CampaignTemplate(_message.Message):
    __slots__ = ("unique_id", "startup_template", "experiment_template", "closeout_template", "name", "plannable_parameters", "planner_allocations")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    STARTUP_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    EXPERIMENT_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    CLOSEOUT_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PLANNABLE_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    PLANNER_ALLOCATIONS_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    startup_template: _experiment_template_pb2.ExperimentTemplate
    experiment_template: _experiment_template_pb2.ExperimentTemplate
    closeout_template: _experiment_template_pb2.ExperimentTemplate
    name: str
    plannable_parameters: _containers.RepeatedCompositeFieldContainer[_parameter_metadata_pb2.ParameterMetadata]
    planner_allocations: _containers.RepeatedCompositeFieldContainer[_planner_allocation_pb2.PlannerAllocation]
    def __init__(self, unique_id: _Optional[str] = ..., startup_template: _Optional[_Union[_experiment_template_pb2.ExperimentTemplate, _Mapping]] = ..., experiment_template: _Optional[_Union[_experiment_template_pb2.ExperimentTemplate, _Mapping]] = ..., closeout_template: _Optional[_Union[_experiment_template_pb2.ExperimentTemplate, _Mapping]] = ..., name: _Optional[str] = ..., plannable_parameters: _Optional[_Iterable[_Union[_parameter_metadata_pb2.ParameterMetadata, _Mapping]]] = ..., planner_allocations: _Optional[_Iterable[_Union[_planner_allocation_pb2.PlannerAllocation, _Mapping]]] = ...) -> None: ...



import ares_struct_pb2 as _ares_struct_pb2
from device import device_status_pb2 as _device_status_pb2
from google.protobuf import empty_pb2 as _empty_pb2
import ares_data_schema_pb2 as _ares_data_schema_pb2
from device import device_command_descriptor_pb2 as _device_command_descriptor_pb2
from device import device_execution_result_pb2 as _device_execution_result_pb2
from device import device_polling_settings_pb2 as _device_polling_settings_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeviceInfoResponse(_message.Message):
    __slots__ = ("name", "version", "description")
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    version: str
    description: str
    def __init__(self, name: _Optional[str] = ..., version: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class SettingsSchemaResponse(_message.Message):
    __slots__ = ("schema",)
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    schema: _ares_data_schema_pb2.AresDataSchema
    def __init__(self, schema: _Optional[_Union[_ares_data_schema_pb2.AresDataSchema, _Mapping]] = ...) -> None: ...

class CurrentSettingsResponse(_message.Message):
    __slots__ = ("settings",)
    SETTINGS_FIELD_NUMBER: _ClassVar[int]
    settings: _ares_struct_pb2.AresStruct
    def __init__(self, settings: _Optional[_Union[_ares_struct_pb2.AresStruct, _Mapping]] = ...) -> None: ...

class SetSettingsRequest(_message.Message):
    __slots__ = ("settings",)
    SETTINGS_FIELD_NUMBER: _ClassVar[int]
    settings: _ares_struct_pb2.AresStruct
    def __init__(self, settings: _Optional[_Union[_ares_struct_pb2.AresStruct, _Mapping]] = ...) -> None: ...

class CommandsResponse(_message.Message):
    __slots__ = ("commands",)
    COMMANDS_FIELD_NUMBER: _ClassVar[int]
    commands: _containers.RepeatedCompositeFieldContainer[_device_command_descriptor_pb2.DeviceCommandDescriptor]
    def __init__(self, commands: _Optional[_Iterable[_Union[_device_command_descriptor_pb2.DeviceCommandDescriptor, _Mapping]]] = ...) -> None: ...

class DeviceStateStreamRequest(_message.Message):
    __slots__ = ("polling_settings",)
    POLLING_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    polling_settings: _device_polling_settings_pb2.DevicePollingSettings
    def __init__(self, polling_settings: _Optional[_Union[_device_polling_settings_pb2.DevicePollingSettings, _Mapping]] = ...) -> None: ...

class StateSchemaResponse(_message.Message):
    __slots__ = ("schema",)
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    schema: _ares_data_schema_pb2.AresDataSchema
    def __init__(self, schema: _Optional[_Union[_ares_data_schema_pb2.AresDataSchema, _Mapping]] = ...) -> None: ...

class DeviceStateResponse(_message.Message):
    __slots__ = ("state",)
    STATE_FIELD_NUMBER: _ClassVar[int]
    state: _ares_struct_pb2.AresStruct
    def __init__(self, state: _Optional[_Union[_ares_struct_pb2.AresStruct, _Mapping]] = ...) -> None: ...

class ExecuteCommandRequest(_message.Message):
    __slots__ = ("command_name", "arguments")
    COMMAND_NAME_FIELD_NUMBER: _ClassVar[int]
    ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
    command_name: str
    arguments: _ares_struct_pb2.AresStruct
    def __init__(self, command_name: _Optional[str] = ..., arguments: _Optional[_Union[_ares_struct_pb2.AresStruct, _Mapping]] = ...) -> None: ...



from templates import parameter_metadata_pb2 as _parameter_metadata_pb2
from templates import output_metadata_pb2 as _output_metadata_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CommandMetadata(_message.Message):
    __slots__ = ("unique_id", "name", "description", "device_id", "output_metadata", "parameter_metadatas", "device_type")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_METADATA_FIELD_NUMBER: _ClassVar[int]
    PARAMETER_METADATAS_FIELD_NUMBER: _ClassVar[int]
    DEVICE_TYPE_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    name: str
    description: str
    device_id: str
    output_metadata: _output_metadata_pb2.OutputMetadata
    parameter_metadatas: _containers.RepeatedCompositeFieldContainer[_parameter_metadata_pb2.ParameterMetadata]
    device_type: str
    def __init__(self, unique_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., device_id: _Optional[str] = ..., output_metadata: _Optional[_Union[_output_metadata_pb2.OutputMetadata, _Mapping]] = ..., parameter_metadatas: _Optional[_Iterable[_Union[_parameter_metadata_pb2.ParameterMetadata, _Mapping]]] = ..., device_type: _Optional[str] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'visualizing/visualizer_info.proto')
_sym_db = _symbol_database.Default()
from ..visualizing import visualizer_capabilities_pb2 as visualizing_dot_visualizer__capabilities__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!visualizing/visualizer_info.proto\x12\x1aares.datamodel.visualizing\x1a)visualizing/visualizer_capabilities.proto"\xa7\x01\n\x0eVisualizerInfo\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x18\n\x0bdescription\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x10\n\x03url\x18\x06 \x01(\tH\x02\x88\x01\x01B\x0c\n\n_unique_idB\x0e\n\x0c_descriptionB\x06\n\x04_urlb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'visualizing.visualizer_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_VISUALIZERINFO']._serialized_start = 109
    _globals['_VISUALIZERINFO']._serialized_end = 276


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'connection/connection_status.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n"connection/connection_status.proto\x12\x19ares.datamodel.connection"\'\n\x17ConnectionStatusRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"W\n\x10ConnectionStatus\x125\n\x06status\x18\x01 \x01(\x0e2%.ares.datamodel.connection.AresStatus\x12\x0c\n\x04info\x18\x02 \x01(\t*L\n\nAresStatus\x12\x1d\n\x19UNKNOWN_CONNECTION_STATUS\x10\x00\x12\r\n\tCONNECTED\x10\x01\x12\x10\n\x0cDISCONNECTED\x10\x02b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connection.connection_status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ARESSTATUS']._serialized_start = 195
    _globals['_ARESSTATUS']._serialized_end = 271
    _globals['_CONNECTIONSTATUSREQUEST']._serialized_start = 65
    _globals['_CONNECTIONSTATUSREQUEST']._serialized_end = 104
    _globals['_CONNECTIONSTATUS']._serialized_start = 106
    _globals['_CONNECTIONSTATUS']._serialized_end = 193


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_event.proto')
_sym_db = _symbol_database.Default()
from . import ares_notification_pb2 as ares__notification__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10ares_event.proto\x12\rares.services\x1a\x17ares_notification.proto"\x15\n\x13NotificationRequest"N\n\x14NotificationResponse\x126\n\rnotifications\x18\x01 \x03(\x0b2\x1f.ares.services.AresNotification2\xcb\x01\n\tAresEvent\x12^\n\x13GetAllNotifications\x12".ares.services.NotificationRequest\x1a#.ares.services.NotificationResponse\x12^\n\x15GetNotificationStream\x12".ares.services.NotificationRequest\x1a\x1f.ares.services.AresNotification0\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_NOTIFICATIONREQUEST']._serialized_start = 60
    _globals['_NOTIFICATIONREQUEST']._serialized_end = 81
    _globals['_NOTIFICATIONRESPONSE']._serialized_start = 83
    _globals['_NOTIFICATIONRESPONSE']._serialized_end = 161
    _globals['_ARESEVENT']._serialized_start = 164
    _globals['_ARESEVENT']._serialized_end = 367


from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNSPECIFIED_STATE: _ClassVar[State]
    ACTIVE: _ClassVar[State]
    INACTIVE: _ClassVar[State]
    ERROR: _ClassVar[State]
UNSPECIFIED_STATE: State
ACTIVE: State
INACTIVE: State
ERROR: State

class StateRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class StateResponse(_message.Message):
    __slots__ = ("state", "state_message")
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATE_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    state: State
    state_message: str
    def __init__(self, state: _Optional[_Union[State, str]] = ..., state_message: _Optional[str] = ...) -> None: ...



import limits_pb2 as _limits_pb2
from google.protobuf import any_pb2 as _any_pb2
import ares_data_schema_pb2 as _ares_data_schema_pb2
import ares_struct_pb2 as _ares_struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParameterMetadata(_message.Message):
    __slots__ = ("unique_id", "name", "unit", "constraints", "index", "output_name", "not_plannable", "use_default", "schema", "planner_name", "planner_description", "initial_value", "extra_info")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_NAME_FIELD_NUMBER: _ClassVar[int]
    NOT_PLANNABLE_FIELD_NUMBER: _ClassVar[int]
    USE_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    PLANNER_NAME_FIELD_NUMBER: _ClassVar[int]
    PLANNER_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    INITIAL_VALUE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_INFO_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    name: str
    unit: str
    constraints: _containers.RepeatedCompositeFieldContainer[_limits_pb2.Limits]
    index: int
    output_name: str
    not_plannable: bool
    use_default: bool
    schema: _ares_data_schema_pb2.SchemaEntry
    planner_name: str
    planner_description: str
    initial_value: _ares_struct_pb2.AresValue
    extra_info: _any_pb2.Any
    def __init__(self, unique_id: _Optional[str] = ..., name: _Optional[str] = ..., unit: _Optional[str] = ..., constraints: _Optional[_Iterable[_Union[_limits_pb2.Limits, _Mapping]]] = ..., index: _Optional[int] = ..., output_name: _Optional[str] = ..., not_plannable: bool = ..., use_default: bool = ..., schema: _Optional[_Union[_ares_data_schema_pb2.SchemaEntry, _Mapping]] = ..., planner_name: _Optional[str] = ..., planner_description: _Optional[str] = ..., initial_value: _Optional[_Union[_ares_struct_pb2.AresValue, _Mapping]] = ..., extra_info: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ScriptExecutionRequest(_message.Message):
    __slots__ = ("script",)
    SCRIPT_FIELD_NUMBER: _ClassVar[int]
    script: str
    def __init__(self, script: _Optional[str] = ...) -> None: ...

class ScriptExecutionOutput(_message.Message):
    __slots__ = ("output",)
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    output: str
    def __init__(self, output: _Optional[str] = ...) -> None: ...



from device import device_state_request_filter_pb2 as _device_state_request_filter_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExportType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNSPECIFIED: _ClassVar[ExportType]
    COMBINED: _ClassVar[ExportType]
    ZIPPED: _ClassVar[ExportType]
UNSPECIFIED: ExportType
COMBINED: ExportType
ZIPPED: ExportType

class DeviceStateRequest(_message.Message):
    __slots__ = ("filter", "export_type")
    FILTER_FIELD_NUMBER: _ClassVar[int]
    EXPORT_TYPE_FIELD_NUMBER: _ClassVar[int]
    filter: _device_state_request_filter_pb2.DeviceStateRequestFilter
    export_type: ExportType
    def __init__(self, filter: _Optional[_Union[_device_state_request_filter_pb2.DeviceStateRequestFilter, _Mapping]] = ..., export_type: _Optional[_Union[ExportType, str]] = ...) -> None: ...

class DeviceStateResponse(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    def __init__(self, data: _Optional[bytes] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Project(_message.Message):
    __slots__ = ("unique_id", "name", "description")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    name: str
    description: str
    def __init__(self, unique_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...



"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings
from . import ares_devices_pb2 as ares__devices__pb2
from . import ares_struct_pb2 as ares__struct__pb2
from .device import device_execution_result_pb2 as device_dot_device__execution__result__pb2
from .device import device_info_pb2 as device_dot_device__info__pb2
from .device import device_logging_settings_pb2 as device_dot_device__logging__settings__pb2
from .device import device_settings_pb2 as device_dot_device__settings__pb2
from .device import device_status_pb2 as device_dot_device__status__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from .templates import command_template_pb2 as templates_dot_command__template__pb2
GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(f'The grpc package installed is at version {GRPC_VERSION},' + ' but the generated code in ares_devices_pb2_grpc.py depends on' + f' grpcio>={GRPC_GENERATED_VERSION}.' + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}' + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.')

class AresDevicesStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListAresDevices = channel.unary_unary('/ares.services.device.AresDevices/ListAresDevices', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__devices__pb2.ListAresDevicesResponse.FromString, _registered_method=True)
        self.GetDeviceInfo = channel.unary_unary('/ares.services.device.AresDevices/GetDeviceInfo', request_serializer=ares__devices__pb2.DeviceInfoRequest.SerializeToString, response_deserializer=device_dot_device__info__pb2.DeviceInfo.FromString, _registered_method=True)
        self.GetServerSerialPorts = channel.unary_unary('/ares.services.device.AresDevices/GetServerSerialPorts', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__devices__pb2.ListServerSerialPortsResponse.FromString, _registered_method=True)
        self.GetDeviceStatus = channel.unary_unary('/ares.services.device.AresDevices/GetDeviceStatus', request_serializer=ares__devices__pb2.DeviceStatusRequest.SerializeToString, response_deserializer=device_dot_device__status__pb2.DeviceOperationalStatus.FromString, _registered_method=True)
        self.GetCommandMetadatas = channel.unary_unary('/ares.services.device.AresDevices/GetCommandMetadatas', request_serializer=ares__devices__pb2.CommandMetadatasRequest.SerializeToString, response_deserializer=ares__devices__pb2.CommandMetadatasResponse.FromString, _registered_method=True)
        self.ExecuteCommand = channel.unary_unary('/ares.services.device.AresDevices/ExecuteCommand', request_serializer=templates_dot_command__template__pb2.CommandTemplate.SerializeToString, response_deserializer=device_dot_device__execution__result__pb2.DeviceExecutionResult.FromString, _registered_method=True)
        self.GetAllDeviceConfigs = channel.unary_unary('/ares.services.device.AresDevices/GetAllDeviceConfigs', request_serializer=ares__devices__pb2.DeviceConfigRequest.SerializeToString, response_deserializer=ares__devices__pb2.DeviceConfigResponse.FromString, _registered_method=True)
        self.Activate = channel.unary_unary('/ares.services.device.AresDevices/Activate', request_serializer=ares__devices__pb2.DeviceActivateRequest.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.SetDeviceSettings = channel.unary_unary('/ares.services.device.AresDevices/SetDeviceSettings', request_serializer=device_dot_device__settings__pb2.DeviceSettings.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.GetDeviceSettings = channel.unary_unary('/ares.services.device.AresDevices/GetDeviceSettings', request_serializer=ares__devices__pb2.DeviceSettingsRequest.SerializeToString, response_deserializer=ares__struct__pb2.AresStruct.FromString, _registered_method=True)
        self.GetDeviceState = channel.unary_unary('/ares.services.device.AresDevices/GetDeviceState', request_serializer=ares__devices__pb2.DeviceStateRequest.SerializeToString, response_deserializer=ares__devices__pb2.DeviceStateResponse.FromString, _registered_method=True)
        self.GetDeviceStateStream = channel.unary_stream('/ares.services.device.AresDevices/GetDeviceStateStream', request_serializer=ares__devices__pb2.DeviceStateStreamRequest.SerializeToString, response_deserializer=ares__devices__pb2.DeviceStateResponse.FromString, _registered_method=True)
        self.GetDeviceStateSchema = channel.unary_unary('/ares.services.device.AresDevices/GetDeviceStateSchema', request_serializer=ares__devices__pb2.DeviceStateSchemaRequest.SerializeToString, response_deserializer=ares__devices__pb2.DeviceStateSchemaResponse.FromString, _registered_method=True)
        self.SetDeviceLoggerSettings = channel.unary_unary('/ares.services.device.AresDevices/SetDeviceLoggerSettings', request_serializer=device_dot_device__logging__settings__pb2.DeviceLoggingSettings.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.GetDeviceLoggerSettings = channel.unary_unary('/ares.services.device.AresDevices/GetDeviceLoggerSettings', request_serializer=ares__devices__pb2.DeviceLoggerSettingsRequest.SerializeToString, response_deserializer=device_dot_device__logging__settings__pb2.DeviceLoggingSettings.FromString, _registered_method=True)
        self.GetDeviceLoggers = channel.unary_unary('/ares.services.device.AresDevices/GetDeviceLoggers', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__devices__pb2.DeviceLoggersResponse.FromString, _registered_method=True)
        self.ListRemoteAresDevices = channel.unary_unary('/ares.services.device.AresDevices/ListRemoteAresDevices', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__devices__pb2.ListAresRemoteDevicesResponse.FromString, _registered_method=True)
        self.AddRemoteDevice = channel.unary_unary('/ares.services.device.AresDevices/AddRemoteDevice', request_serializer=ares__devices__pb2.AddRemoteDeviceRequest.SerializeToString, response_deserializer=ares__devices__pb2.AddRemoteDeviceResponse.FromString, _registered_method=True)
        self.RemoveRemoteDevice = channel.unary_unary('/ares.services.device.AresDevices/RemoveRemoteDevice', request_serializer=ares__devices__pb2.RemoveRemoteDeviceRequest.SerializeToString, response_deserializer=ares__devices__pb2.RemoveRemoteDeviceResponse.FromString, _registered_method=True)
        self.UpdateRemoteDevice = channel.unary_unary('/ares.services.device.AresDevices/UpdateRemoteDevice', request_serializer=ares__devices__pb2.UpdateRemoteDeviceRequest.SerializeToString, response_deserializer=ares__devices__pb2.UpdateRemoteDeviceResponse.FromString, _registered_method=True)
        self.GetAllRemoteDevicesConfigs = channel.unary_unary('/ares.services.device.AresDevices/GetAllRemoteDevicesConfigs', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__devices__pb2.RemoteDeviceConfigResponse.FromString, _registered_method=True)

class AresDevicesServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListAresDevices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServerSerialPorts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCommandMetadatas(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllDeviceConfigs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Activate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDeviceSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceStateStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceStateSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDeviceLoggerSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceLoggerSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceLoggers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRemoteAresDevices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddRemoteDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveRemoteDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRemoteDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllRemoteDevicesConfigs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_AresDevicesServicer_to_server(servicer, server):
    rpc_method_handlers = {'ListAresDevices': grpc.unary_unary_rpc_method_handler(servicer.ListAresDevices, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__devices__pb2.ListAresDevicesResponse.SerializeToString), 'GetDeviceInfo': grpc.unary_unary_rpc_method_handler(servicer.GetDeviceInfo, request_deserializer=ares__devices__pb2.DeviceInfoRequest.FromString, response_serializer=device_dot_device__info__pb2.DeviceInfo.SerializeToString), 'GetServerSerialPorts': grpc.unary_unary_rpc_method_handler(servicer.GetServerSerialPorts, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__devices__pb2.ListServerSerialPortsResponse.SerializeToString), 'GetDeviceStatus': grpc.unary_unary_rpc_method_handler(servicer.GetDeviceStatus, request_deserializer=ares__devices__pb2.DeviceStatusRequest.FromString, response_serializer=device_dot_device__status__pb2.DeviceOperationalStatus.SerializeToString), 'GetCommandMetadatas': grpc.unary_unary_rpc_method_handler(servicer.GetCommandMetadatas, request_deserializer=ares__devices__pb2.CommandMetadatasRequest.FromString, response_serializer=ares__devices__pb2.CommandMetadatasResponse.SerializeToString), 'ExecuteCommand': grpc.unary_unary_rpc_method_handler(servicer.ExecuteCommand, request_deserializer=templates_dot_command__template__pb2.CommandTemplate.FromString, response_serializer=device_dot_device__execution__result__pb2.DeviceExecutionResult.SerializeToString), 'GetAllDeviceConfigs': grpc.unary_unary_rpc_method_handler(servicer.GetAllDeviceConfigs, request_deserializer=ares__devices__pb2.DeviceConfigRequest.FromString, response_serializer=ares__devices__pb2.DeviceConfigResponse.SerializeToString), 'Activate': grpc.unary_unary_rpc_method_handler(servicer.Activate, request_deserializer=ares__devices__pb2.DeviceActivateRequest.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'SetDeviceSettings': grpc.unary_unary_rpc_method_handler(servicer.SetDeviceSettings, request_deserializer=device_dot_device__settings__pb2.DeviceSettings.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'GetDeviceSettings': grpc.unary_unary_rpc_method_handler(servicer.GetDeviceSettings, request_deserializer=ares__devices__pb2.DeviceSettingsRequest.FromString, response_serializer=ares__struct__pb2.AresStruct.SerializeToString), 'GetDeviceState': grpc.unary_unary_rpc_method_handler(servicer.GetDeviceState, request_deserializer=ares__devices__pb2.DeviceStateRequest.FromString, response_serializer=ares__devices__pb2.DeviceStateResponse.SerializeToString), 'GetDeviceStateStream': grpc.unary_stream_rpc_method_handler(servicer.GetDeviceStateStream, request_deserializer=ares__devices__pb2.DeviceStateStreamRequest.FromString, response_serializer=ares__devices__pb2.DeviceStateResponse.SerializeToString), 'GetDeviceStateSchema': grpc.unary_unary_rpc_method_handler(servicer.GetDeviceStateSchema, request_deserializer=ares__devices__pb2.DeviceStateSchemaRequest.FromString, response_serializer=ares__devices__pb2.DeviceStateSchemaResponse.SerializeToString), 'SetDeviceLoggerSettings': grpc.unary_unary_rpc_method_handler(servicer.SetDeviceLoggerSettings, request_deserializer=device_dot_device__logging__settings__pb2.DeviceLoggingSettings.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'GetDeviceLoggerSettings': grpc.unary_unary_rpc_method_handler(servicer.GetDeviceLoggerSettings, request_deserializer=ares__devices__pb2.DeviceLoggerSettingsRequest.FromString, response_serializer=device_dot_device__logging__settings__pb2.DeviceLoggingSettings.SerializeToString), 'GetDeviceLoggers': grpc.unary_unary_rpc_method_handler(servicer.GetDeviceLoggers, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__devices__pb2.DeviceLoggersResponse.SerializeToString), 'ListRemoteAresDevices': grpc.unary_unary_rpc_method_handler(servicer.ListRemoteAresDevices, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__devices__pb2.ListAresRemoteDevicesResponse.SerializeToString), 'AddRemoteDevice': grpc.unary_unary_rpc_method_handler(servicer.AddRemoteDevice, request_deserializer=ares__devices__pb2.AddRemoteDeviceRequest.FromString, response_serializer=ares__devices__pb2.AddRemoteDeviceResponse.SerializeToString), 'RemoveRemoteDevice': grpc.unary_unary_rpc_method_handler(servicer.RemoveRemoteDevice, request_deserializer=ares__devices__pb2.RemoveRemoteDeviceRequest.FromString, response_serializer=ares__devices__pb2.RemoveRemoteDeviceResponse.SerializeToString), 'UpdateRemoteDevice': grpc.unary_unary_rpc_method_handler(servicer.UpdateRemoteDevice, request_deserializer=ares__devices__pb2.UpdateRemoteDeviceRequest.FromString, response_serializer=ares__devices__pb2.UpdateRemoteDeviceResponse.SerializeToString), 'GetAllRemoteDevicesConfigs': grpc.unary_unary_rpc_method_handler(servicer.GetAllRemoteDevicesConfigs, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__devices__pb2.RemoteDeviceConfigResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('ares.services.device.AresDevices', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ares.services.device.AresDevices', rpc_method_handlers)

class AresDevices(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListAresDevices(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/ListAresDevices', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__devices__pb2.ListAresDevicesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetDeviceInfo(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetDeviceInfo', ares__devices__pb2.DeviceInfoRequest.SerializeToString, device_dot_device__info__pb2.DeviceInfo.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetServerSerialPorts(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetServerSerialPorts', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__devices__pb2.ListServerSerialPortsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetDeviceStatus(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetDeviceStatus', ares__devices__pb2.DeviceStatusRequest.SerializeToString, device_dot_device__status__pb2.DeviceOperationalStatus.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetCommandMetadatas(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetCommandMetadatas', ares__devices__pb2.CommandMetadatasRequest.SerializeToString, ares__devices__pb2.CommandMetadatasResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def ExecuteCommand(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/ExecuteCommand', templates_dot_command__template__pb2.CommandTemplate.SerializeToString, device_dot_device__execution__result__pb2.DeviceExecutionResult.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetAllDeviceConfigs(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetAllDeviceConfigs', ares__devices__pb2.DeviceConfigRequest.SerializeToString, ares__devices__pb2.DeviceConfigResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def Activate(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/Activate', ares__devices__pb2.DeviceActivateRequest.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def SetDeviceSettings(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/SetDeviceSettings', device_dot_device__settings__pb2.DeviceSettings.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetDeviceSettings(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetDeviceSettings', ares__devices__pb2.DeviceSettingsRequest.SerializeToString, ares__struct__pb2.AresStruct.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetDeviceState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetDeviceState', ares__devices__pb2.DeviceStateRequest.SerializeToString, ares__devices__pb2.DeviceStateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetDeviceStateStream(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ares.services.device.AresDevices/GetDeviceStateStream', ares__devices__pb2.DeviceStateStreamRequest.SerializeToString, ares__devices__pb2.DeviceStateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetDeviceStateSchema(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetDeviceStateSchema', ares__devices__pb2.DeviceStateSchemaRequest.SerializeToString, ares__devices__pb2.DeviceStateSchemaResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def SetDeviceLoggerSettings(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/SetDeviceLoggerSettings', device_dot_device__logging__settings__pb2.DeviceLoggingSettings.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetDeviceLoggerSettings(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetDeviceLoggerSettings', ares__devices__pb2.DeviceLoggerSettingsRequest.SerializeToString, device_dot_device__logging__settings__pb2.DeviceLoggingSettings.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetDeviceLoggers(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetDeviceLoggers', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__devices__pb2.DeviceLoggersResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def ListRemoteAresDevices(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/ListRemoteAresDevices', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__devices__pb2.ListAresRemoteDevicesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def AddRemoteDevice(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/AddRemoteDevice', ares__devices__pb2.AddRemoteDeviceRequest.SerializeToString, ares__devices__pb2.AddRemoteDeviceResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def RemoveRemoteDevice(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/RemoveRemoteDevice', ares__devices__pb2.RemoveRemoteDeviceRequest.SerializeToString, ares__devices__pb2.RemoveRemoteDeviceResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def UpdateRemoteDevice(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/UpdateRemoteDevice', ares__devices__pb2.UpdateRemoteDeviceRequest.SerializeToString, ares__devices__pb2.UpdateRemoteDeviceResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetAllRemoteDevicesConfigs(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetAllRemoteDevicesConfigs', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__devices__pb2.RemoteDeviceConfigResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)


import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RequestMetadata(_message.Message):
    __slots__ = ("system_name", "campaign_name", "campaign_id", "experiment_id", "experiment_start_time")
    SYSTEM_NAME_FIELD_NUMBER: _ClassVar[int]
    CAMPAIGN_NAME_FIELD_NUMBER: _ClassVar[int]
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    EXPERIMENT_ID_FIELD_NUMBER: _ClassVar[int]
    EXPERIMENT_START_TIME_FIELD_NUMBER: _ClassVar[int]
    system_name: str
    campaign_name: str
    campaign_id: str
    experiment_id: str
    experiment_start_time: _timestamp_pb2.Timestamp
    def __init__(self, system_name: _Optional[str] = ..., campaign_name: _Optional[str] = ..., campaign_id: _Optional[str] = ..., experiment_id: _Optional[str] = ..., experiment_start_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'planning/planner_service_capabilities.proto')
_sym_db = _symbol_database.Default()
from .. import ares_data_schema_pb2 as ares__data__schema__pb2
from ..planning import planner_pb2 as planning_dot_planner__pb2
from .. import ares_data_type_pb2 as ares__data__type__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+planning/planner_service_capabilities.proto\x12\x17ares.datamodel.planning\x1a\x16ares_data_schema.proto\x1a\x16planning/planner.proto\x1a\x14ares_data_type.proto"\xf8\x01\n\x1aPlannerServiceCapabilities\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x17\n\x0ftimeout_seconds\x18\x02 \x01(\x03\x12<\n\x12available_planners\x18\x03 \x03(\x0b2 .ares.datamodel.planning.Planner\x127\n\x0fsettings_schema\x18\x04 \x01(\x0b2\x1e.ares.datamodel.AresDataSchema\x124\n\x0eaccepted_types\x18\x05 \x03(\x0e2\x1c.ares.datamodel.AresDataTypeb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'planning.planner_service_capabilities_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_PLANNERSERVICECAPABILITIES']._serialized_start = 143
    _globals['_PLANNERSERVICECAPABILITIES']._serialized_end = 391


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'planning/plan.proto')
_sym_db = _symbol_database.Default()
from .. import ares_struct_pb2 as ares__struct__pb2
from .. import ares_data_type_pb2 as ares__data__type__pb2
from .. import ares_outcome_enum_pb2 as ares__outcome__enum__pb2
from .. import request_metadata_pb2 as request__metadata__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13planning/plan.proto\x12\x17ares.datamodel.planning\x1a\x11ares_struct.proto\x1a\x14ares_data_type.proto\x1a\x17ares_outcome_enum.proto\x1a\x16request_metadata.proto"\xdd\x01\n\x0fPlanningRequest\x12G\n\x13planning_parameters\x18\x01 \x03(\x0b2*.ares.datamodel.planning.PlanningParameter\x124\n\x10adapter_settings\x18\x02 \x01(\x0b2\x1a.ares.datamodel.AresStruct\x12\x18\n\x10analysis_results\x18\x03 \x03(\x01\x121\n\x08metadata\x18\x04 \x01(\x0b2\x1f.ares.datamodel.RequestMetadata"\xb8\x01\n\x10PlanningResponse\x12E\n\x12planned_parameters\x18\x01 \x03(\x0b2).ares.datamodel.planning.PlannedParameter\x121\n\x10planning_outcome\x18\x02 \x01(\x0e2\x17.ares.datamodel.Outcome\x12\x19\n\x0cerror_string\x18\x03 \x01(\tH\x00\x88\x01\x01B\x0f\n\r_error_string"\xfa\x03\n\x11PlanningParameter\x12\x16\n\x0eparameter_name\x18\x01 \x01(\t\x12\x1a\n\rminimum_value\x18\x02 \x01(\x01H\x00\x88\x01\x01\x12\x1a\n\rmaximum_value\x18\x03 \x01(\x01H\x01\x88\x01\x01\x12\x1e\n\x11minimum_precision\x18\x04 \x01(\x01H\x02\x88\x01\x01\x12H\n\x11parameter_history\x18\x05 \x03(\x0b2-.ares.datamodel.planning.ParameterHistoryInfo\x12/\n\tdata_type\x18\x06 \x01(\x0e2\x1c.ares.datamodel.AresDataType\x12:\n\x08metadata\x18\x07 \x01(\x0b2(.ares.datamodel.planning.PlannerMetadata\x12\x12\n\nis_planned\x18\x08 \x01(\x08\x12\x11\n\tis_result\x18\t \x01(\x08\x12\x14\n\x0cplanner_name\x18\n \x01(\t\x125\n\rinitial_value\x18\x0b \x01(\x0b2\x19.ares.datamodel.AresValueH\x03\x88\x01\x01B\x10\n\x0e_minimum_valueB\x10\n\x0e_maximum_valueB\x14\n\x12_minimum_precisionB\x10\n\x0e_initial_value"\x93\x01\n\x14ParameterHistoryInfo\x120\n\rplanned_value\x18\x01 \x01(\x0b2\x19.ares.datamodel.AresValue\x126\n\x0eachieved_value\x18\x02 \x01(\x0b2\x19.ares.datamodel.AresValueH\x00\x88\x01\x01B\x11\n\x0f_achieved_value"\x9a\x01\n\x10PlannedParameter\x12\x16\n\x0eparameter_name\x18\x01 \x01(\t\x122\n\x0fparameter_value\x18\x02 \x01(\x0b2\x19.ares.datamodel.AresValue\x12:\n\x08metadata\x18\x03 \x01(\x0b2(.ares.datamodel.planning.PlannerMetadata"(\n\x0fPlannerMetadata\x12\x15\n\rmetadata_name\x18\x01 \x01(\tb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'planning.plan_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_PLANNINGREQUEST']._serialized_start = 139
    _globals['_PLANNINGREQUEST']._serialized_end = 360
    _globals['_PLANNINGRESPONSE']._serialized_start = 363
    _globals['_PLANNINGRESPONSE']._serialized_end = 547
    _globals['_PLANNINGPARAMETER']._serialized_start = 550
    _globals['_PLANNINGPARAMETER']._serialized_end = 1056
    _globals['_PARAMETERHISTORYINFO']._serialized_start = 1059
    _globals['_PARAMETERHISTORYINFO']._serialized_end = 1206
    _globals['_PLANNEDPARAMETER']._serialized_start = 1209
    _globals['_PLANNEDPARAMETER']._serialized_end = 1363
    _globals['_PLANNERMETADATA']._serialized_start = 1365
    _globals['_PLANNERMETADATA']._serialized_end = 1405


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'experiment_overview.proto')
_sym_db = _symbol_database.Default()
from .templates import experiment_template_pb2 as templates_dot_experiment__template__pb2
from .templates import parameter_pb2 as templates_dot_parameter__pb2
from . import ares_struct_pb2 as ares__struct__pb2
from . import analysis_overview_pb2 as analysis__overview__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19experiment_overview.proto\x12\x0eares.datamodel\x1a#templates/experiment_template.proto\x1a\x19templates/parameter.proto\x1a\x11ares_struct.proto\x1a\x17analysis_overview.proto"\x9c\x02\n\x12ExperimentOverview\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12>\n\x08template\x18\x02 \x01(\x0b2,.ares.datamodel.templates.ExperimentTemplate\x12*\n\x06result\x18\x03 \x01(\x0b2\x1a.ares.datamodel.AresStruct\x127\n\nparameters\x18\x04 \x03(\x0b2#.ares.datamodel.templates.Parameter\x12;\n\x11analysis_overview\x18\x05 \x01(\x0b2 .ares.datamodel.AnalysisOverviewB\x0c\n\n_unique_idb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'experiment_overview_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_EXPERIMENTOVERVIEW']._serialized_start = 154
    _globals['_EXPERIMENTOVERVIEW']._serialized_end = 438


"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings
from . import ares_planner_management_service_pb2 as ares__planner__management__service__pb2
from . import ares_struct_pb2 as ares__struct__pb2
from .connection import connection_state_pb2 as connection_dot_connection__state__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from .planning import manual_planner_pb2 as planning_dot_manual__planner__pb2
from .planning import planner_settings_pb2 as planning_dot_planner__settings__pb2
GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(f'The grpc package installed is at version {GRPC_VERSION},' + ' but the generated code in ares_planner_management_service_pb2_grpc.py depends on' + f' grpcio>={GRPC_GENERATED_VERSION}.' + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}' + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.')

class AresPlannerManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetState = channel.unary_unary('/ares.services.AresPlannerManagementService/GetState', request_serializer=connection_dot_connection__state__pb2.StateRequest.SerializeToString, response_deserializer=connection_dot_connection__state__pb2.StateResponse.FromString, _registered_method=True)
        self.GetInfo = channel.unary_unary('/ares.services.AresPlannerManagementService/GetInfo', request_serializer=ares__planner__management__service__pb2.PlannerInfoRequest.SerializeToString, response_deserializer=ares__planner__management__service__pb2.PlannerInfoResponse.FromString, _registered_method=True)
        self.SetPlannerSettings = channel.unary_unary('/ares.services.AresPlannerManagementService/SetPlannerSettings', request_serializer=planning_dot_planner__settings__pb2.PlannerSettings.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.GetPlannerSettings = channel.unary_unary('/ares.services.AresPlannerManagementService/GetPlannerSettings', request_serializer=ares__planner__management__service__pb2.PlannerSettingsRequest.SerializeToString, response_deserializer=ares__struct__pb2.AresStruct.FromString, _registered_method=True)
        self.SeedManualPlanner = channel.unary_unary('/ares.services.AresPlannerManagementService/SeedManualPlanner', request_serializer=planning_dot_manual__planner__pb2.ManualPlannerSeed.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.GetManualPlannerSeed = channel.unary_unary('/ares.services.AresPlannerManagementService/GetManualPlannerSeed', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=planning_dot_manual__planner__pb2.ManualPlannerSetCollection.FromString, _registered_method=True)
        self.ResetManualPlanner = channel.unary_unary('/ares.services.AresPlannerManagementService/ResetManualPlanner', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.GetAllPlanners = channel.unary_unary('/ares.services.AresPlannerManagementService/GetAllPlanners', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__planner__management__service__pb2.GetAllPlannersResponse.FromString, _registered_method=True)
        self.AddPlanner = channel.unary_unary('/ares.services.AresPlannerManagementService/AddPlanner', request_serializer=ares__planner__management__service__pb2.AddPlannerRequest.SerializeToString, response_deserializer=ares__planner__management__service__pb2.AddPlannerResponse.FromString, _registered_method=True)
        self.UpdatePlanner = channel.unary_unary('/ares.services.AresPlannerManagementService/UpdatePlanner', request_serializer=ares__planner__management__service__pb2.UpdatePlannerRequest.SerializeToString, response_deserializer=ares__planner__management__service__pb2.UpdatePlannerResponse.FromString, _registered_method=True)
        self.RemovePlanner = channel.unary_unary('/ares.services.AresPlannerManagementService/RemovePlanner', request_serializer=ares__planner__management__service__pb2.RemovePlannerRequest.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)

class AresPlannerManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetPlannerSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPlannerSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SeedManualPlanner(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetManualPlannerSeed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetManualPlanner(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllPlanners(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddPlanner(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePlanner(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemovePlanner(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_AresPlannerManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'GetState': grpc.unary_unary_rpc_method_handler(servicer.GetState, request_deserializer=connection_dot_connection__state__pb2.StateRequest.FromString, response_serializer=connection_dot_connection__state__pb2.StateResponse.SerializeToString), 'GetInfo': grpc.unary_unary_rpc_method_handler(servicer.GetInfo, request_deserializer=ares__planner__management__service__pb2.PlannerInfoRequest.FromString, response_serializer=ares__planner__management__service__pb2.PlannerInfoResponse.SerializeToString), 'SetPlannerSettings': grpc.unary_unary_rpc_method_handler(servicer.SetPlannerSettings, request_deserializer=planning_dot_planner__settings__pb2.PlannerSettings.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'GetPlannerSettings': grpc.unary_unary_rpc_method_handler(servicer.GetPlannerSettings, request_deserializer=ares__planner__management__service__pb2.PlannerSettingsRequest.FromString, response_serializer=ares__struct__pb2.AresStruct.SerializeToString), 'SeedManualPlanner': grpc.unary_unary_rpc_method_handler(servicer.SeedManualPlanner, request_deserializer=planning_dot_manual__planner__pb2.ManualPlannerSeed.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'GetManualPlannerSeed': grpc.unary_unary_rpc_method_handler(servicer.GetManualPlannerSeed, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=planning_dot_manual__planner__pb2.ManualPlannerSetCollection.SerializeToString), 'ResetManualPlanner': grpc.unary_unary_rpc_method_handler(servicer.ResetManualPlanner, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'GetAllPlanners': grpc.unary_unary_rpc_method_handler(servicer.GetAllPlanners, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__planner__management__service__pb2.GetAllPlannersResponse.SerializeToString), 'AddPlanner': grpc.unary_unary_rpc_method_handler(servicer.AddPlanner, request_deserializer=ares__planner__management__service__pb2.AddPlannerRequest.FromString, response_serializer=ares__planner__management__service__pb2.AddPlannerResponse.SerializeToString), 'UpdatePlanner': grpc.unary_unary_rpc_method_handler(servicer.UpdatePlanner, request_deserializer=ares__planner__management__service__pb2.UpdatePlannerRequest.FromString, response_serializer=ares__planner__management__service__pb2.UpdatePlannerResponse.SerializeToString), 'RemovePlanner': grpc.unary_unary_rpc_method_handler(servicer.RemovePlanner, request_deserializer=ares__planner__management__service__pb2.RemovePlannerRequest.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('ares.services.AresPlannerManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ares.services.AresPlannerManagementService', rpc_method_handlers)

class AresPlannerManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresPlannerManagementService/GetState', connection_dot_connection__state__pb2.StateRequest.SerializeToString, connection_dot_connection__state__pb2.StateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetInfo(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresPlannerManagementService/GetInfo', ares__planner__management__service__pb2.PlannerInfoRequest.SerializeToString, ares__planner__management__service__pb2.PlannerInfoResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def SetPlannerSettings(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresPlannerManagementService/SetPlannerSettings', planning_dot_planner__settings__pb2.PlannerSettings.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetPlannerSettings(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresPlannerManagementService/GetPlannerSettings', ares__planner__management__service__pb2.PlannerSettingsRequest.SerializeToString, ares__struct__pb2.AresStruct.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def SeedManualPlanner(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresPlannerManagementService/SeedManualPlanner', planning_dot_manual__planner__pb2.ManualPlannerSeed.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetManualPlannerSeed(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresPlannerManagementService/GetManualPlannerSeed', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, planning_dot_manual__planner__pb2.ManualPlannerSetCollection.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def ResetManualPlanner(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresPlannerManagementService/ResetManualPlanner', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetAllPlanners(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresPlannerManagementService/GetAllPlanners', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__planner__management__service__pb2.GetAllPlannersResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def AddPlanner(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresPlannerManagementService/AddPlanner', ares__planner__management__service__pb2.AddPlannerRequest.SerializeToString, ares__planner__management__service__pb2.AddPlannerResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def UpdatePlanner(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresPlannerManagementService/UpdatePlanner', ares__planner__management__service__pb2.UpdatePlannerRequest.SerializeToString, ares__planner__management__service__pb2.UpdatePlannerResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def RemovePlanner(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresPlannerManagementService/RemovePlanner', ares__planner__management__service__pb2.RemovePlannerRequest.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'templates/parameter.proto')
_sym_db = _symbol_database.Default()
from ..templates import parameter_metadata_pb2 as templates_dot_parameter__metadata__pb2
from ..templates import variable_allocation_pb2 as templates_dot_variable__allocation__pb2
from .. import ares_struct_pb2 as ares__struct__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19templates/parameter.proto\x12\x18ares.datamodel.templates\x1a"templates/parameter_metadata.proto\x1a#templates/variable_allocation.proto\x1a\x11ares_struct.proto"\xf7\x02\n\tParameter\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12=\n\x08metadata\x18\x02 \x01(\x0b2+.ares.datamodel.templates.ParameterMetadata\x12(\n\x05value\x18\x03 \x01(\x0b2\x19.ares.datamodel.AresValue\x12\x0f\n\x07planned\x18\x04 \x01(\x08\x12\x19\n\x11environment_based\x18\x05 \x01(\x08\x12F\n\x11planning_metadata\x18\x06 \x01(\x0b2+.ares.datamodel.templates.ParameterMetadata\x12=\n\rvariable_type\x18\x07 \x01(\x0e2&.ares.datamodel.templates.VariableType\x12\x19\n\x11variable_argument\x18\x08 \x01(\t\x12\r\n\x05index\x18\t \x01(\x03B\x0c\n\n_unique_idb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'templates.parameter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_PARAMETER']._serialized_start = 148
    _globals['_PARAMETER']._serialized_end = 523


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'device_state_export_service.proto')
_sym_db = _symbol_database.Default()
from .device import device_state_request_filter_pb2 as device_dot_device__state__request__filter__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!device_state_export_service.proto\x12\rares.services\x1a(device/device_state_request_filter.proto"\x85\x01\n\x12DeviceStateRequest\x12?\n\x06filter\x18\x01 \x01(\x0b2/.ares.datamodel.device.DeviceStateRequestFilter\x12.\n\x0bexport_type\x18\x02 \x01(\x0e2\x19.ares.services.ExportType"#\n\x13DeviceStateResponse\x12\x0c\n\x04data\x18\x01 \x01(\x0c*7\n\nExportType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08COMBINED\x10\x01\x12\n\n\x06ZIPPED\x10\x022s\n\x18DeviceStateExportService\x12W\n\x0eGetStateExport\x12!.ares.services.DeviceStateRequest\x1a".ares.services.DeviceStateResponseb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device_state_export_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_EXPORTTYPE']._serialized_start = 267
    _globals['_EXPORTTYPE']._serialized_end = 322
    _globals['_DEVICESTATEREQUEST']._serialized_start = 95
    _globals['_DEVICESTATEREQUEST']._serialized_end = 228
    _globals['_DEVICESTATERESPONSE']._serialized_start = 230
    _globals['_DEVICESTATERESPONSE']._serialized_end = 265
    _globals['_DEVICESTATEEXPORTSERVICE']._serialized_start = 324
    _globals['_DEVICESTATEEXPORTSERVICE']._serialized_end = 439


"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings
GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(f'The grpc package installed is at version {GRPC_VERSION},' + ' but the generated code in ares_campaign_tag_pb2_grpc.py depends on' + f' grpcio>={GRPC_GENERATED_VERSION}.' + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}' + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.')


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'device/device_status.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1adevice/device_status.proto\x12\x15ares.datamodel.device"n\n\x17DeviceOperationalStatus\x12B\n\x11operational_state\x18\x01 \x01(\x0e2\'.ares.datamodel.device.OperationalState\x12\x0f\n\x07message\x18\x02 \x01(\t*H\n\x10OperationalState\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08INACTIVE\x10\x01\x12\n\n\x06ACTIVE\x10\x02\x12\t\n\x05ERROR\x10\x03b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.device_status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_OPERATIONALSTATE']._serialized_start = 165
    _globals['_OPERATIONALSTATE']._serialized_end = 237
    _globals['_DEVICEOPERATIONALSTATUS']._serialized_start = 53
    _globals['_DEVICEOPERATIONALSTATUS']._serialized_end = 163


"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings
from ...device import device_execution_result_pb2 as device_dot_device__execution__result__pb2
from ...device import device_status_pb2 as device_dot_device__status__pb2
from ...device.remote import ares_remote_device_service_pb2 as device_dot_remote_dot_ares__remote__device__service__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(f'The grpc package installed is at version {GRPC_VERSION},' + ' but the generated code in device/remote/ares_remote_device_service_pb2_grpc.py depends on' + f' grpcio>={GRPC_GENERATED_VERSION}.' + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}' + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.')

class AresRemoteDeviceServiceStub(object):
    """defines a contract for ares to use in order to talk to a remote device
    designed to be similar to the internal ARES device implementation
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetOperationalStatus = channel.unary_unary('/ares.datamodel.device.remote.AresRemoteDeviceService/GetOperationalStatus', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=device_dot_device__status__pb2.DeviceOperationalStatus.FromString, _registered_method=True)
        self.GetInfo = channel.unary_unary('/ares.datamodel.device.remote.AresRemoteDeviceService/GetInfo', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=device_dot_remote_dot_ares__remote__device__service__pb2.DeviceInfoResponse.FromString, _registered_method=True)
        self.GetCommands = channel.unary_unary('/ares.datamodel.device.remote.AresRemoteDeviceService/GetCommands', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=device_dot_remote_dot_ares__remote__device__service__pb2.CommandsResponse.FromString, _registered_method=True)
        self.ExecuteCommand = channel.unary_unary('/ares.datamodel.device.remote.AresRemoteDeviceService/ExecuteCommand', request_serializer=device_dot_remote_dot_ares__remote__device__service__pb2.ExecuteCommandRequest.SerializeToString, response_deserializer=device_dot_device__execution__result__pb2.DeviceExecutionResult.FromString, _registered_method=True)
        self.EnterSafeMode = channel.unary_unary('/ares.datamodel.device.remote.AresRemoteDeviceService/EnterSafeMode', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.GetSettingsSchema = channel.unary_unary('/ares.datamodel.device.remote.AresRemoteDeviceService/GetSettingsSchema', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=device_dot_remote_dot_ares__remote__device__service__pb2.SettingsSchemaResponse.FromString, _registered_method=True)
        self.GetCurrentSettings = channel.unary_unary('/ares.datamodel.device.remote.AresRemoteDeviceService/GetCurrentSettings', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=device_dot_remote_dot_ares__remote__device__service__pb2.CurrentSettingsResponse.FromString, _registered_method=True)
        self.SetSettings = channel.unary_unary('/ares.datamodel.device.remote.AresRemoteDeviceService/SetSettings', request_serializer=device_dot_remote_dot_ares__remote__device__service__pb2.SetSettingsRequest.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.GetStateSchema = channel.unary_unary('/ares.datamodel.device.remote.AresRemoteDeviceService/GetStateSchema', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=device_dot_remote_dot_ares__remote__device__service__pb2.StateSchemaResponse.FromString, _registered_method=True)
        self.GetState = channel.unary_unary('/ares.datamodel.device.remote.AresRemoteDeviceService/GetState', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=device_dot_remote_dot_ares__remote__device__service__pb2.DeviceStateResponse.FromString, _registered_method=True)
        self.GetStateStream = channel.unary_stream('/ares.datamodel.device.remote.AresRemoteDeviceService/GetStateStream', request_serializer=device_dot_remote_dot_ares__remote__device__service__pb2.DeviceStateStreamRequest.SerializeToString, response_deserializer=device_dot_remote_dot_ares__remote__device__service__pb2.DeviceStateResponse.FromString, _registered_method=True)

class AresRemoteDeviceServiceServicer(object):
    """defines a contract for ares to use in order to talk to a remote device
    designed to be similar to the internal ARES device implementation
    """

    def GetOperationalStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCommands(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnterSafeMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSettingsSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCurrentSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStateSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStateStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_AresRemoteDeviceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'GetOperationalStatus': grpc.unary_unary_rpc_method_handler(servicer.GetOperationalStatus, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=device_dot_device__status__pb2.DeviceOperationalStatus.SerializeToString), 'GetInfo': grpc.unary_unary_rpc_method_handler(servicer.GetInfo, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=device_dot_remote_dot_ares__remote__device__service__pb2.DeviceInfoResponse.SerializeToString), 'GetCommands': grpc.unary_unary_rpc_method_handler(servicer.GetCommands, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=device_dot_remote_dot_ares__remote__device__service__pb2.CommandsResponse.SerializeToString), 'ExecuteCommand': grpc.unary_unary_rpc_method_handler(servicer.ExecuteCommand, request_deserializer=device_dot_remote_dot_ares__remote__device__service__pb2.ExecuteCommandRequest.FromString, response_serializer=device_dot_device__execution__result__pb2.DeviceExecutionResult.SerializeToString), 'EnterSafeMode': grpc.unary_unary_rpc_method_handler(servicer.EnterSafeMode, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'GetSettingsSchema': grpc.unary_unary_rpc_method_handler(servicer.GetSettingsSchema, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=device_dot_remote_dot_ares__remote__device__service__pb2.SettingsSchemaResponse.SerializeToString), 'GetCurrentSettings': grpc.unary_unary_rpc_method_handler(servicer.GetCurrentSettings, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=device_dot_remote_dot_ares__remote__device__service__pb2.CurrentSettingsResponse.SerializeToString), 'SetSettings': grpc.unary_unary_rpc_method_handler(servicer.SetSettings, request_deserializer=device_dot_remote_dot_ares__remote__device__service__pb2.SetSettingsRequest.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'GetStateSchema': grpc.unary_unary_rpc_method_handler(servicer.GetStateSchema, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=device_dot_remote_dot_ares__remote__device__service__pb2.StateSchemaResponse.SerializeToString), 'GetState': grpc.unary_unary_rpc_method_handler(servicer.GetState, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=device_dot_remote_dot_ares__remote__device__service__pb2.DeviceStateResponse.SerializeToString), 'GetStateStream': grpc.unary_stream_rpc_method_handler(servicer.GetStateStream, request_deserializer=device_dot_remote_dot_ares__remote__device__service__pb2.DeviceStateStreamRequest.FromString, response_serializer=device_dot_remote_dot_ares__remote__device__service__pb2.DeviceStateResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('ares.datamodel.device.remote.AresRemoteDeviceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ares.datamodel.device.remote.AresRemoteDeviceService', rpc_method_handlers)

class AresRemoteDeviceService(object):
    """defines a contract for ares to use in order to talk to a remote device
    designed to be similar to the internal ARES device implementation
    """

    @staticmethod
    def GetOperationalStatus(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.device.remote.AresRemoteDeviceService/GetOperationalStatus', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, device_dot_device__status__pb2.DeviceOperationalStatus.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetInfo(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.device.remote.AresRemoteDeviceService/GetInfo', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, device_dot_remote_dot_ares__remote__device__service__pb2.DeviceInfoResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetCommands(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.device.remote.AresRemoteDeviceService/GetCommands', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, device_dot_remote_dot_ares__remote__device__service__pb2.CommandsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def ExecuteCommand(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.device.remote.AresRemoteDeviceService/ExecuteCommand', device_dot_remote_dot_ares__remote__device__service__pb2.ExecuteCommandRequest.SerializeToString, device_dot_device__execution__result__pb2.DeviceExecutionResult.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def EnterSafeMode(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.device.remote.AresRemoteDeviceService/EnterSafeMode', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetSettingsSchema(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.device.remote.AresRemoteDeviceService/GetSettingsSchema', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, device_dot_remote_dot_ares__remote__device__service__pb2.SettingsSchemaResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetCurrentSettings(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.device.remote.AresRemoteDeviceService/GetCurrentSettings', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, device_dot_remote_dot_ares__remote__device__service__pb2.CurrentSettingsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def SetSettings(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.device.remote.AresRemoteDeviceService/SetSettings', device_dot_remote_dot_ares__remote__device__service__pb2.SetSettingsRequest.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetStateSchema(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.device.remote.AresRemoteDeviceService/GetStateSchema', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, device_dot_remote_dot_ares__remote__device__service__pb2.StateSchemaResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.datamodel.device.remote.AresRemoteDeviceService/GetState', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, device_dot_remote_dot_ares__remote__device__service__pb2.DeviceStateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetStateStream(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ares.datamodel.device.remote.AresRemoteDeviceService/GetStateStream', device_dot_remote_dot_ares__remote__device__service__pb2.DeviceStateStreamRequest.SerializeToString, device_dot_remote_dot_ares__remote__device__service__pb2.DeviceStateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)


from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Limits(_message.Message):
    __slots__ = ("unique_id", "minimum", "maximum", "index")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    MINIMUM_FIELD_NUMBER: _ClassVar[int]
    MAXIMUM_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    minimum: float
    maximum: float
    index: int
    def __init__(self, unique_id: _Optional[str] = ..., minimum: _Optional[float] = ..., maximum: _Optional[float] = ..., index: _Optional[int] = ...) -> None: ...
